==> liba8cas-1.2.0.tar.gz: liba8cas-1.2.0/src/fsk_mod.h <==
/*
 * Copyright (c) 2010 Tomasz Krasuski (see AUTHORS)
 *
 * This file is part of the A8CAS project which allows to manipulate tape
 * images for Atari 8-bit computers.
 *
 * A8CAS is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * A8CAS is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along
 * with A8CAS; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 */
#ifndef FSK_MOD_H
#define FSK_MOD_H

typedef struct FSK_MOD_t FSK_MOD_t;

struct FSK_MOD_t {
	void (*gen_func)(FSK_MOD_t *mod, void *buffer, unsigned int num_samples, int signal);
	unsigned int num_channels;
	unsigned int write_channel;
	double mark_wave_step;
	double space_wave_step;
	double wave_pos;
};

void FSK_MOD_init(FSK_MOD_t *mod, unsigned int samplerate, unsigned int bits, unsigned int num_channels, unsigned int write_channel, double mark_freq, double space_freq);

/* When num_channels > 1, BUFFER must be empty - this function writes only one
   channel of sound, leaving others untouched. */
void FSK_MOD_generate(FSK_MOD_t *mod, void *buffer, unsigned int num_samples, int signal);

#endif /* FSK_MOD_H */

==> liba8cas-1.3.1.tar.gz: liba8cas-1.3.1/src/fsk_mod.h <==
/*
 * Copyright (c) 2010-2011 A8CAS developers (see AUTHORS)
 *
 * This file is part of the A8CAS project which allows to manipulate tape
 * images for Atari 8-bit computers.
 *
 * A8CAS is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * A8CAS is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along
 * with A8CAS; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 */
#ifndef FSK_MOD_H
#define FSK_MOD_H

typedef struct FSK_MOD_t FSK_MOD_t;

struct FSK_MOD_t {
	void (*gen_func)(FSK_MOD_t *mod, void *buffer, unsigned int num_samples, int signal);
	unsigned int num_channels;
	unsigned int write_channel;
	float mark_wave_step;
	float space_wave_step;
	float wave_pos;
	float volume;
};

void FSK_MOD_init(FSK_MOD_t *mod, unsigned int samplerate, unsigned int bits, unsigned int num_channels, unsigned int write_channel, double mark_freq, double space_freq);

void FSK_MOD_set_volume(FSK_MOD_t *mod, float volume);

/* When num_channels > 1, BUFFER must be empty - this function writes only one
   channel of sound, leaving others untouched. */
void FSK_MOD_generate(FSK_MOD_t *mod, void *buffer, unsigned int num_samples, int signal);

#endif /* FSK_MOD_H */
